@@ -18,11 +18,12 @@ class MessageHandler(UpdateHandler):
 
     async def callback(self) -> None:
         text = self.get_reply_text()
-        markup = self.get_reply_markup()
-        await self.reply(text, markup)
+        if text:
+            markup = self.get_reply_markup()
+            await self.reply(text, markup)
 
-    def get_reply_text(self) -> str:
-        return self.get_validated_field("reply_text", self.reply_text)
+    def get_reply_text(self) -> str | None:
+        return self.reply_text
 
     def get_reply_markup(self) -> ReplyMarkup | None:
         return self.reply_markup
